@@ -338,9 +338,7 @@ resolve_address (SoupDNSCacheEntry *entry)
 
 	memset (&hints, 0, sizeof (struct addrinfo));
 #  ifdef AI_ADDRCONFIG
-	hints.ai_flags = AI_CANONNAME | AI_ADDRCONFIG;
-#  else
-	hints.ai_flags = AI_CANONNAME;
+	hints.ai_flags = AI_ADDRCONFIG;
 #  endif
 	hints.ai_family = PF_UNSPEC;
 	hints.ai_socktype = SOCK_STREAM;
@@ -520,10 +518,10 @@ do_async_callback (gpointer user_data)
 	SoupDNSCacheEntry *entry = lookup->entry;
 	GCancellable *cancellable = lookup->cancellable;
 
-	lookup->callback (lookup, resolve_status (entry, cancellable),
-			  lookup->user_data);
 	if (cancellable)
 		g_signal_handlers_disconnect_by_func (cancellable, async_cancel, lookup);
+	lookup->callback (lookup, resolve_status (entry, cancellable),
+			  lookup->user_data);
 
 	return FALSE;
 }
